Crate swiftui_sys

Crate swiftui_sys 

Raw FFI bindings to SwiftUI via a generated Swift @_cdecl bridge.

This crate is auto-generated by swift-bridge-gen. Do not edit manually. The ergonomic API is in the swiftui crate.

All functions require libSwiftUIBridge.dylib to be loaded via dlopen before use. Use load to load and resolve all symbols.

Citation

@software{rswift,
  author       = {Eugene Hauptmann},
  title        = {rswift},
  year         = {2025},
  url          = {https://github.com/eugenehp/rswift},
  note         = {Build native Apple apps from Rust}
}

License

GPL-3.0 — Copyright © 2025 Eugene Hauptmann

Structs

Fns
All resolved function pointers from the Swift bridge dylib.

Functions

load
Load the Swift bridge dylib and resolve all symbols.

Type Aliases

Handle